package TestApp2;

use strict;
use warnings;
use Mouse;

extends 'TestApp';


1;
